@@ -6,13 +6,14 @@
 #     Licensed under Apache License v2
 ################################################################################
 # Version
-from .__version__ import __version__
+from .__version__ import __version__, __nlp_version__
 if __name__ == "__main__":
     module_type = 'Running'
 else:
     module_type = 'Imported'
-version_number = __version__
-print("""Imported Auto_ViML version: %s. Call using:
+viml_version_number = __version__
+nlp_version_number = __nlp_version__
+print("""%s Auto_ViML version: %s. Call using:
              m, feats, trainm, testm = Auto_ViML(train, target, test,
                             sample_submission='',
                             scoring_parameter='', KMeans_Featurizer=False,
@@ -20,7 +21,12 @@ print("""Imported Auto_ViML version: %s. Call using:
                              Boosting_Flag='CatBoost', Binning_Flag=False,
                             Add_Poly=0, Stacking_Flag=False,Imbalanced_Flag=False,
                             verbose=1)
-            """ %version_number)
-print('Now Auto_ViML can solve multi-label, multi-output problems. Also Auto_NLP included.')
-print('To get the latest version, perform "pip install autoviml --no-cache-dir --ignore-installed"')
+            """ %(module_type, viml_version_number))
+print()
 ###########################################################################################
+print("""%s Auto_NLP version: %s.. Call using:
+     train_nlp, test_nlp, nlp_pipeline, predictions = Auto_NLP(
+                nlp_column, train, test, target, score_type='balanced_accuracy',
+                modeltype='Classification',top_num_features=200, verbose=0,
+                build_model=True)""" %(module_type, nlp_version_number))
+########################################################################
